@@ -961,6 +961,8 @@ class ArgumentParser(OptionalsParser, CsvActionsParser):
         self.__main_func = None
         # pre-parse functions to execute for this parser
         self.__pre_parse = []
+        # defaults setting functions to execute for this parser
+        self.__reset_defaults = []
 
         # Store parent parsers allowing for separating parsing args meant for
         # the root command with args targeted to subcommands. This enables
@@ -1076,8 +1078,17 @@ class ArgumentParser(OptionalsParser, CsvActionsParser):
                     parsers.update(x._name_parser_map)
         return ImmutableDict(parsers)
 
-    def _parse_known_args(self, arg_strings, namespace):
-        """Add support for using a specified, default subparser."""
+    def pre_parse(self, arg_strings=None, namespace=None):
+        """Reset registered defaults and pre-parse functions."""
+        if arg_strings is None:
+            arg_strings = []
+        if namespace is None:
+            namespace = Namespace()
+
+        # reset any flagged defaults
+        for functor, parser in self.__reset_defaults:
+            functor(parser, namespace)
+
         # run registered pre-parse functions
         if self.__pre_parse:
             for functor, parser in self.__pre_parse:
@@ -1087,7 +1098,11 @@ class ArgumentParser(OptionalsParser, CsvActionsParser):
             # wipe pre-parse functions so they only run once
             del self.__pre_parse[:]
 
-        # parse the remaining args
+        return namespace, arg_strings
+
+    def _parse_known_args(self, arg_strings, namespace):
+        """Add support for running registered pre-parse functions."""
+        namespace, arg_strings = self.pre_parse(arg_strings, namespace)
         return super()._parse_known_args(arg_strings, namespace)
 
     def parse_args(self, args=None, namespace=None):
@@ -1171,6 +1186,11 @@ class ArgumentParser(OptionalsParser, CsvActionsParser):
         obj.bind_to_parser(self)
         return self
 
+    def bind_reset_defaults(self, functor):
+        """Decorator to bind a function for resetting defaults before every parse run."""
+        self.__reset_defaults.append((functor, self))
+        return functor
+
     def bind_delayed_default(self, priority, name=None):
         def f(functor, name=name):
             if name is None:
