@@ -1,17 +1,15 @@
-# Copyright: 2009-2011 Brian Harring <ferringb@gmail.com>
-# Copyright: 2005 Marien Zwart <marienz@gentoo.org>
-# License: BSD/GPL2
-
 import errno
 import inspect
+import io
 import os
 import shutil
 import stat
 import sys
 import tempfile
 
-from snakeoil.test import TestCase
-from snakeoil import compatibility
+from . import TestCase
+from ..compatibility import IGNORED_EXCEPTIONS
+
 
 class TempDirMixin(TestCase):
 
@@ -44,12 +42,10 @@ def tempdir_decorator(func):
     f.__name__ = func.__name__
     return f
 
-mk_named_tempfile = tempfile.NamedTemporaryFile
-if compatibility.is_py3k:
-    import io
-    def mk_named_tempfile(*args, **kwds):
-        tmp_f = tempfile.NamedTemporaryFile(*args, **kwds)
-        return io.TextIOWrapper(tmp_f)
+
+def mk_named_tempfile(*args, **kwds):
+    tmp_f = tempfile.NamedTemporaryFile(*args, **kwds)
+    return io.TextIOWrapper(tmp_f)
 
 
 class PythonNamespaceWalker(object):
@@ -63,15 +59,12 @@ class PythonNamespaceWalker(object):
     # TODO: Update this for pypy's naming, and jythons.
     abi_target = 'cpython-%i%i' % tuple(sys.version_info[:2])
 
-    module_blacklist = set([
-        'snakeoil.cli.arghparse', 'snakeoil.dist.generate_man_rsts',
+    module_blacklist = frozenset([
+        'snakeoil.cli.arghparse', 'snakeoil.pickling',
     ])
-    if not compatibility.is_py3k:
-        module_blacklist.update(['snakeoil.dist.caching_2to3'])
-    module_blacklist = frozenset(module_blacklist)
 
     def _default_module_blacklister(self, target):
-        return target in self.module_blacklist
+        return target in self.module_blacklist or target.startswith('snakeoil.dist')
 
     def walk_namespace(self, namespace, **kwds):
         location = os.path.abspath(os.path.dirname(
@@ -166,7 +159,7 @@ class PythonNamespaceWalker(object):
         for chunk in namespace.split(".")[1:]:
             try:
                 obj = getattr(obj, chunk)
-            except compatibility.IGNORED_EXCEPTIONS:
+            except IGNORED_EXCEPTIONS:
                 raise
             except AttributeError:
                 raise AssertionError("failed importing target %s" % namespace)
